@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2016-12-29'; # DATE
-our $VERSION = '1.68'; # VERSION
+our $DATE = '2017-01-04'; # DATE
+our $VERSION = '1.69'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -291,8 +291,8 @@ sub hook_format_result {
 
     if ($fmt eq 'html+datatables') {
         $fmt = 'text-pretty';
-        $ENV{VIEW_RESULT} = 1;
-        $ENV{FORMAT_PRETTY_TABLE_BACKEND} = 'Text::Table::HTML::DataTables';
+        $ENV{VIEW_RESULT} //= 1;
+        $ENV{FORMAT_PRETTY_TABLE_BACKEND} //= 'Text::Table::HTML::DataTables';
     }
 
     my $fres = Perinci::Result::Format::Lite::format(
@@ -523,7 +523,7 @@ Perinci::CmdLine::Lite - A Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.68 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2016-12-29.
+This document describes version 1.69 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-01-04.
 
 =head1 SYNOPSIS
 
@@ -759,7 +759,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
